from odoo import models, fields, api


class ResUsers(models.Model):
    _inherit = 'res.users'

    employee_id = fields.Many2one(
        'hr.employee', 'Employee', compute='_compute_employee_data')
    hr_job_id = fields.Many2one(
        'hr.job', 'Job Position', compute='_compute_employee_data')
    hr_department_id = fields.Many2one(
        'hr.department', 'Department', compute='_compute_employee_data')
    hr_manager_id = fields.Many2one(
        'hr.employee', 'Manager', compute='_compute_employee_data')
    hr_coach_id = fields.Many2one(
        'hr.employee', 'Coach', compute='_compute_employee_data')

    @api.depends('employee_ids', 'employee_ids.job_id',
                 'employee_ids.department_id', 'employee_ids.parent_id',
                 'employee_ids.coach_id')
    def _compute_employee_data(self):
        for record in self:
            # We can compute employee-related data only when there is only one
            # employee linked to user
            if len(record.employee_ids) == 1:
                e = record.employee_ids
                record.update({
                    'employee_id': e.id,
                    'hr_job_id': e.job_id.id,
                    'hr_department_id': e.department_id.id,
                    'hr_manager_id': e.parent_id.id,
                    'hr_coach_id': e.coach_id.id,
                })
            else:
                record.update({
                    'employee_id': False,
                    'hr_job_id': False,
                    'hr_department_id': False,
                    'hr_manager_id': False,
                    'hr_coach_id': False,
                })
